@@ -2,9 +2,9 @@ from __future__ import annotations
 
 from typing import Any
 
+from clinicedc_constants import NEW, OPEN
 from django.db.models import QuerySet
 
-from edc_constants.constants import NEW, OPEN
 from edc_sites.site import sites
 
 from ..models import ActionItem
