@@ -1,9 +1,8 @@
 from typing import Any
 
+from clinicedc_constants import NEVER, OTHER, YES
 from django import forms
 
-from edc_constants.constants import NEVER, OTHER, YES
-
 
 class MedicationAdherenceFormValidatorMixin:
     def clean(self: Any):
