@@ -1,7 +1,6 @@
+from clinicedc_constants import NOT_APPLICABLE
 from django.db import models
 
-from edc_constants.constants import NOT_APPLICABLE
-
 
 class AeFollowupMethodsModelMixin(models.Model):
     def __str__(self):
