@@ -33,11 +33,7 @@ class AesiModelMixin(
         abstract = True
         verbose_name = "AE of Special Interest Report"
         indexes = (
-            NonUniqueSubjectIdentifierFieldMixin.Meta.indexes
-            + ActionModelMixin.Meta.indexes
-            + [
-                models.Index(
-                    fields=["subject_identifier", "action_identifier", "site", "id"]
-                )
-            ]
+            *NonUniqueSubjectIdentifierFieldMixin.Meta.indexes,
+            *ActionModelMixin.Meta.indexes,
+            models.Index(fields=["subject_identifier", "action_identifier", "site", "id"]),
         )
