@@ -8,7 +8,7 @@ from django.conf import settings
 from django.urls import reverse
 
 from edc_model.models import BaseUuidModel
-from edc_utils import convert_php_dateformat
+from edc_utils.text import convert_php_dateformat
 
 if TYPE_CHECKING:
     from django.contrib import admin
