@@ -23,7 +23,7 @@ class Appointment(AppointmentModelMixin, SiteModelMixin, BaseUuidModel):
         )
 
     # noinspection PyTypeHints
-    natural_key.dependencies = ["sites.Site"]  # type: ignore
+    natural_key.dependencies = ("sites.Site",)
 
     class Meta(AppointmentModelMixin.Meta, SiteModelMixin.Meta, BaseUuidModel.Meta):
-        indexes = AppointmentModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes
+        indexes = (*AppointmentModelMixin.Meta.indexes, *BaseUuidModel.Meta.indexes)
