@@ -7,6 +7,8 @@ from collections.abc import Callable
 from datetime import datetime
 from typing import TYPE_CHECKING, Any
 
+from clinicedc_constants import CLINIC, NOT_APPLICABLE, OK
+from clinicedc_constants import ERROR as ERROR_CODE
 from dateutil.relativedelta import relativedelta
 from django.apps import apps as django_apps
 from django.conf import settings
@@ -24,8 +26,6 @@ from django.db.models import Count, ProtectedError
 from django.urls import reverse
 from django.utils.translation import gettext as _
 
-from edc_constants.constants import CLINIC, NOT_APPLICABLE, OK
-from edc_constants.constants import ERROR as ERROR_CODE
 from edc_dashboard.url_names import url_names
 from edc_form_validators import INVALID_ERROR
 from edc_metadata.constants import CRF, REQUIRED, REQUISITION
@@ -709,9 +709,8 @@ def skip_appointment(appointment: Appointment, comment: str | None = None):
 
 def get_unscheduled_appointment_url(appointment: Appointment = None) -> str:
     """Returns a url for the unscheduled appointment."""
-    dashboard_url_name = "subject_dashboard_url"
-    dashboard_url = url_names.get(dashboard_url_name)
-    unscheduled_appointment_url_name = "edc_appointment:unscheduled_appointment_url"
+    dashboard_url = url_names.get("subject_dashboard_url")
+    unscheduled_appointment_url = "edc_appointment:unscheduled_appointment_url"
     kwargs = dict(
         subject_identifier=appointment.subject_identifier,
         visit_schedule_name=appointment.visit_schedule_name,
@@ -722,7 +721,7 @@ def get_unscheduled_appointment_url(appointment: Appointment = None) -> str:
     )
     kwargs.update(visit_code_sequence=str(appointment.visit_code_sequence + 1))
     kwargs.update(redirect_url=dashboard_url)
-    return reverse(unscheduled_appointment_url_name, kwargs=kwargs)
+    return reverse(unscheduled_appointment_url, kwargs=kwargs)
 
 
 def update_appt_status_for_timepoint(related_visit: RelatedVisitModel) -> None:
