@@ -7,9 +7,7 @@ class Command(BaseCommand):
     help = "Export users to a CSV file in the current directory"
 
     def add_arguments(self, parser):
-        parser.add_argument(
-            "--csvfile", default=None, dest="csvfile", help="CSV filename"
-        )
+        parser.add_argument("--csvfile", default=None, dest="csvfile", help="CSV filename")
 
         parser.add_argument(
             "--verbose",
@@ -27,5 +25,5 @@ class Command(BaseCommand):
             help="Export new users to file",
         )
 
-    def handle(self, *args, **options):
+    def handle(self, *args, **options):  # noqa: ARG002
         export_users(options["csvfile"])
