@@ -10,7 +10,5 @@ from .signals import (
 )
 from .user_profile import UserProfile
 
-if settings.APP_NAME == "edc_auth" and (
-    "test" in sys.argv or "runtests.py" in sys.argv
-):
+if settings.APP_NAME == "edc_auth" and ("test" in sys.argv or "runtests.py" in sys.argv):
     from ..tests.models import *  # noqa
