@@ -1,7 +1,7 @@
+from clinicedc_constants import NOT_APPLICABLE
 from django.db import models
 
 from edc_constants.choices import YES_NO, YES_NO_NA
-from edc_constants.constants import NOT_APPLICABLE
 
 
 class CitizenFieldsMixin(models.Model):
@@ -13,7 +13,7 @@ class CitizenFieldsMixin(models.Model):
 
     legal_marriage = models.CharField(
         verbose_name=(
-            "If not a citizen, is the participant legally " "married to a Botswana citizen?"
+            "If not a citizen, is the participant legally married to a Botswana citizen?"
         ),
         max_length=3,
         choices=YES_NO_NA,
@@ -25,7 +25,7 @@ class CitizenFieldsMixin(models.Model):
 
     marriage_certificate = models.CharField(
         verbose_name=(
-            "[Interviewer] Has the participant produced " "the marriage certificate as proof? "
+            "[Interviewer] Has the participant produced the marriage certificate as proof? "
         ),
         max_length=3,
         choices=YES_NO_NA,
