@@ -1,4 +1,4 @@
 from .consent_definition_form_validator_mixin import ConsentDefinitionFormValidatorMixin
 from .subject_consent_form_validator import SubjectConsentFormValidatorMixin
 
-__all__ = ["SubjectConsentFormValidatorMixin", "ConsentDefinitionFormValidatorMixin"]
+__all__ = ["ConsentDefinitionFormValidatorMixin", "SubjectConsentFormValidatorMixin"]
