@@ -1,7 +1,10 @@
+import contextlib
+
 from django.db.models.signals import post_save, pre_save
 from django.dispatch import receiver
 
 from edc_sites import site_sites
+from edc_visit_schedule.exceptions import NotOnScheduleError
 from edc_visit_schedule.site_visit_schedules import site_visit_schedules
 from edc_visit_schedule.subject_schedule import SubjectSchedule
 
@@ -69,10 +72,11 @@ def update_appointment_from_consentext_post_save(
             model=instance.subject_consent._meta.label_lower,
             version=instance.subject_consent.version,
         )
-        visit_schedule, schedule = site_visit_schedules.get_by_consent_definition(cdef)
-        subject_schedule = SubjectSchedule(
-            instance.subject_consent.subject_identifier,
-            visit_schedule=visit_schedule,
-            schedule=schedule,
-        )
-        subject_schedule.refresh_appointments()
+        for visit_schedule, schedule in site_visit_schedules.get_by_consent_definition(cdef):
+            subject_schedule = SubjectSchedule(
+                instance.subject_consent.subject_identifier,
+                visit_schedule=visit_schedule,
+                schedule=schedule,
+            )
+            with contextlib.suppress(NotOnScheduleError):
+                subject_schedule.refresh_appointments()
