@@ -23,11 +23,11 @@ class CrfNoManagerModelMixin(
     def natural_key(self) -> tuple:
         return self.related_visit.natural_key()
 
-    natural_key.dependencies = [
+    natural_key.dependencies = (
         settings.SUBJECT_VISIT_MODEL,
         "sites.Site",
         "edc_appointment.appointment",
-    ]
+    )
 
     class Meta:
         abstract = True
