@@ -2,10 +2,9 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
+from clinicedc_constants import UUID_PATTERN
 from django.urls.conf import re_path
 
-from edc_constants.constants import UUID_PATTERN
-
 from .url_names import url_names
 
 if TYPE_CHECKING:
@@ -17,25 +16,44 @@ if TYPE_CHECKING:
     class View(UrlRequestContextMixin, BaseView): ...
 
 
+class UrlConfigError(Exception):
+    pass
+
+
 class UrlConfig:
+    """A class to generate url_patterns for edc DashboardViews,
+    ListBoardViews and SubjectReviewDashboardView.
+
+    * registers the url_with_namespace to `url_names`
+    * The pretty url uses the `url_names_key` less the '_url' suffix
+    * the url pattern name is the same as the given `url_names_key`
+
+    """
+
     def __init__(
         self,
         *,
-        url_name: str,
+        url_names_key: str,
         namespace: str,
         view_class: type[View | UrlRequestContextMixin],
-        label: str,
         identifier_label: str,
         identifier_pattern: str,
     ):
+        if not url_names_key.endswith("_url"):
+            raise UrlConfigError(
+                f"Invalid `url_names_key`. Must end with '_url'. Got {url_names_key}."
+            )
+        self.url_pattern_name = url_names_key
+        self.url_pretty_label = url_names_key.replace("_url", "")
+        self.view_class = view_class
         self.identifier_label = identifier_label
         self.identifier_pattern = identifier_pattern
-        self.label = label
-        self.url_name = url_name
-        self.view_class = view_class
 
-        # register {urlname, namespace:urlname} with url_names
-        url_names.register(url=self.url_name, namespace=namespace)
+        # register with url_names dictionary / registry
+        url_names.register(
+            key=url_names_key,
+            url_with_namespace=f"{namespace}:{self.url_pattern_name}",
+        )
 
     @property
     def dashboard_urls(self) -> list[URLPattern]:
@@ -49,13 +67,13 @@ class UrlConfig:
                 r"(?P<visit_code>\w+)/"
                 r"(?P<unscheduled>\w+)/".format(
                     **dict(
-                        label=self.label,
+                        label=self.url_pretty_label,
                         identifier_label=self.identifier_label,
                         identifier_pattern=self.identifier_pattern,
                     )
                 ),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             ),
             re_path(
                 "{label}/"
@@ -64,13 +82,13 @@ class UrlConfig:
                 r"(?P<schedule_name>\w+)/"
                 r"(?P<visit_code>\w+)/".format(
                     **dict(
-                        label=self.label,
+                        label=self.url_pretty_label,
                         identifier_label=self.identifier_label,
                         identifier_pattern=self.identifier_pattern,
                     )
                 ),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             ),
             re_path(
                 "{label}/"
@@ -79,14 +97,14 @@ class UrlConfig:
                 r"(?P<scanning>\d)/"
                 r"(?P<error>\d)/".format(
                     **dict(
-                        label=self.label,
+                        label=self.url_pretty_label,
                         identifier_label=self.identifier_label,
                         identifier_pattern=self.identifier_pattern,
                         uuid_pattern=UUID_PATTERN.pattern,
                     )
                 ),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             ),
             re_path(
                 "{label}/"
@@ -94,52 +112,52 @@ class UrlConfig:
                 "(?P<appointment>{uuid_pattern})/"
                 r"(?P<reason>\w+)/".format(
                     **dict(
-                        label=self.label,
+                        label=self.url_pretty_label,
                         identifier_label=self.identifier_label,
                         identifier_pattern=self.identifier_pattern,
                         uuid_pattern=UUID_PATTERN.pattern,
                     )
                 ),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             ),
             re_path(
                 "{label}/"
                 "(?P<{identifier_label}>{identifier_pattern})/"
                 "(?P<appointment>{uuid_pattern})/".format(
                     **dict(
-                        label=self.label,
+                        label=self.url_pretty_label,
                         identifier_label=self.identifier_label,
                         identifier_pattern=self.identifier_pattern,
                         uuid_pattern=UUID_PATTERN.pattern,
                     )
                 ),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             ),
             re_path(
                 "{label}/"
                 "(?P<{identifier_label}>{identifier_pattern})/"
                 r"(?P<schedule_name>\w+)/".format(
                     **dict(
-                        label=self.label,
+                        label=self.url_pretty_label,
                         identifier_label=self.identifier_label,
                         identifier_pattern=self.identifier_pattern,
                     )
                 ),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             ),
             re_path(
                 "{label}/(?P<{identifier_label}>{identifier_pattern})/".format(
                     **dict(
-                        label=self.label,
+                        label=self.url_pretty_label,
                         identifier_label=self.identifier_label,
                         identifier_pattern=self.identifier_pattern,
                     )
                 ),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             ),
         ]
 
@@ -154,34 +172,34 @@ class UrlConfig:
                 "{label}/(?P<{identifier_label}>{identifier_pattern})/"
                 r"(?P<page>\d+)/".format(
                     **dict(
-                        label=self.label,
+                        label=self.url_pretty_label,
                         identifier_label=self.identifier_label,
                         identifier_pattern=self.identifier_pattern,
                     )
                 ),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             ),
             re_path(
                 "{label}/(?P<{identifier_label}>{identifier_pattern})/".format(
                     **dict(
-                        label=self.label,
+                        label=self.url_pretty_label,
                         identifier_label=self.identifier_label,
                         identifier_pattern=self.identifier_pattern,
                     )
                 ),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             ),
             re_path(
-                r"{label}/(?P<page>\d+)/".format(**dict(label=self.label)),
+                r"{label}/(?P<page>\d+)/".format(**dict(label=self.url_pretty_label)),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             ),
             re_path(
-                r"{label}/".format(**dict(label=self.label)),
+                r"{label}/".format(**dict(label=self.url_pretty_label)),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             ),
         ]
 
@@ -192,14 +210,14 @@ class UrlConfig:
                 "{label}/(?P<{identifier_label}>{identifier_pattern})/"
                 "(?P<appointment>{uuid_pattern})/".format(
                     **dict(
-                        label=self.label,
+                        label=self.url_pretty_label,
                         identifier_label=self.identifier_label,
                         identifier_pattern=self.identifier_pattern,
                         uuid_pattern=UUID_PATTERN.pattern,
                     )
                 ),
                 self.view_class.as_view(),
-                name=self.url_name,
+                name=self.url_pattern_name,
             )
         ]
         url_patterns.extend(self.listboard_urls)
