@@ -1,9 +1,9 @@
 from typing import Any
 
+from clinicedc_constants import COMPLETE
 from django.db import models
 
 from edc_constants.choices import DOCUMENT_STATUS
-from edc_constants.constants import COMPLETE
 
 
 class DocumentStatusModelMixin(models.Model):
