@@ -1,7 +1,7 @@
+from clinicedc_constants import NOT_APPLICABLE
 from django.db import models
 
 from edc_constants.choices import YES_NO_NA
-from edc_constants.constants import NOT_APPLICABLE
 
 
 class FollowupReviewModelMixin(models.Model):
