@@ -1,7 +1,7 @@
+from clinicedc_constants import YES
 from django.db import models
 
 from edc_constants.choices import YES_NO
-from edc_constants.constants import YES
 from edc_model import models as edc_models
 from edc_model.utils import duration_to_date
 
