@@ -3,11 +3,10 @@ from typing import Any
 from django.contrib import messages
 from django.contrib.auth.models import User
 from django.views.generic.base import TemplateView
-
 from edc_dashboard.view_mixins import EdcViewMixin
 from edc_navbar import NavbarViewMixin
 
-from ..exportables import Exportables
+from ..exportable_models_for_user import ExportableModelsForUser
 
 
 class ExportModelsView(EdcViewMixin, NavbarViewMixin, TemplateView):
@@ -24,5 +23,5 @@ class ExportModelsView(EdcViewMixin, NavbarViewMixin, TemplateView):
             else:
                 messages.info(self.request, "Nothing has been exported.")
         user = User.objects.get(username=self.request.user)
-        kwargs.update(exportables=Exportables(request=self.request, user=user))
+        kwargs.update(exportables=ExportableModelsForUser(request=self.request, user=user))
         return super().get_context_data(**kwargs)
