@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-from datetime import datetime
 from typing import TYPE_CHECKING
 
 from django.conf import settings
@@ -12,27 +11,19 @@ from django.urls.base import reverse
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
 from django.views.generic.base import TemplateView
-
 from edc_dashboard.view_mixins import EdcViewMixin
 
-from ..archive_exporter import (
-    ArchiveExporter,
-    ArchiveExporterEmailError,
-    ArchiveExporterNothingExported,
-)
-from ..exportables import Exportables
+from ..constants import CSV
+from ..exportable_models_for_user import ExportableModelsForUser
 from ..files_emailer import FilesEmailerError
 from ..model_options import ModelOptions
-from ..models import DataRequest, DataRequestHistory
+from ..models_to_file import ModelsToFile, ModelsToFileNothingExportedError
+from ..utils import email_files_to_user, update_data_request_history
 
 if TYPE_CHECKING:
     from django.core.handlers.wsgi import WSGIRequest
 
 
-class NothingToExport(Exception):
-    pass
-
-
 class ExportModelsViewError(Exception):
     pass
 
@@ -50,7 +41,7 @@ class ExportSelectedModelsView(EdcViewMixin, TemplateView):
             )
         return super().get_context_data(**kwargs)
 
-    def post(self, request: WSGIRequest, *args, **kwargs) -> HttpResponseRedirect:
+    def post(self, request: WSGIRequest, *args, **kwargs) -> HttpResponseRedirect:  # noqa: ARG002
         if not self.check_user(request):
             pass
         elif not request.user.email:
@@ -65,15 +56,45 @@ class ExportSelectedModelsView(EdcViewMixin, TemplateView):
                 ),
             )
         else:
-            try:
-                self.export_models(request=request, email_to_user=True)
-            except NothingToExport:
+            selected_models = self.check_export_permissions(
+                self.get_selected_models_from_session(request)
+                or self.get_selected_models_from_post(request)
+            )
+            selected_models = [x.label_lower for x in selected_models]
+            if not selected_models:
                 messages.warning(
                     request,
                     "Nothing to do. Select one or more models and try again.",
                 )
-            except FilesEmailerError as e:
-                messages.error(request, f"Failed to send the data you requested. Got '{e}'")
+            else:
+                try:
+                    models_to_file = ModelsToFile(
+                        models=selected_models,
+                        user=request.user,
+                        archive_to_single_file=True,
+                        export_format=CSV,
+                    )
+                except ModelsToFileNothingExportedError as e:
+                    messages.warning(request, f"Nothing to do. {e}.")
+                else:
+                    if settings.DEBUG:
+                        messages.success(
+                            request,
+                            (
+                                "Your data request has been saved to "
+                                f"{models_to_file.archive_filename}. settings.DEBUG=True."
+                            ),
+                        )
+                        update_data_request_history(request, models_to_file)
+                    else:
+                        try:
+                            email_files_to_user(request, models_to_file)
+                        except FilesEmailerError as e:
+                            messages.error(
+                                request, f"Failed to send the data you requested. Got '{e}'"
+                            )
+                        update_data_request_history(request, models_to_file)
+
         url = reverse(self.post_action_url, kwargs=self.kwargs)
         return HttpResponseRedirect(url)
 
@@ -81,61 +102,12 @@ class ExportSelectedModelsView(EdcViewMixin, TemplateView):
     def check_export_permissions(selected_models) -> list[ModelOptions]:
         return selected_models
 
-    def export_models(self, request: WSGIRequest = None, email_to_user=None):
-        selected_models = self.check_export_permissions(
-            self.get_selected_models_from_session(request)
-            or self.get_selected_models_from_post(request)
-        )
-        selected_models = [x.label_lower for x in selected_models]
-        email_to_user = False if settings.DEBUG else email_to_user
-        archive = True if settings.DEBUG else False
-        try:
-            exporter = ArchiveExporter(
-                models=selected_models,
-                user=request.user,
-                email_to_user=email_to_user,
-                archive=archive,
-            )
-        except (ArchiveExporterEmailError, ConnectionRefusedError) as e:
-            messages.error(request, f"Failed to send files by email. Got '{e}'")
-        except ArchiveExporterNothingExported:
-            messages.info(request, "Nothing to export.")
-        else:
-            if email_to_user:
-                msg = (
-                    f"Your data request has been sent to {request.user.email}. "
-                    "Please check your email."
-                )
-            else:
-                msg = f"Your data request has been saved to {exporter.archive_filename}. "
-
-            messages.success(request, msg)
-            summary = [str(x) for x in exporter.exported]
-            summary.sort()
-            data_request = DataRequest.objects.create(
-                name=f'Data request {datetime.now().strftime("%Y%m%d%H%M")}',
-                models="\n".join(selected_models),
-                user_created=request.user.username,
-                site=request.site,
-            )
-            DataRequestHistory.objects.create(
-                data_request=data_request,
-                exported_datetime=exporter.exported_datetime,
-                summary="\n".join(summary),
-                user_created=request.user.username,
-                user_modified=request.user.username,
-                archive_filename=exporter.archive_filename,
-                emailed_to=exporter.emailed_to,
-                emailed_datetime=exporter.emailed_datetime,
-                site=request.site,
-            )
-
     @staticmethod
     def get_selected_models_from_post(request: WSGIRequest) -> list[ModelOptions]:
         """Returns a list of selected models from the POST
         as ModelOptions.
         """
-        exportables = Exportables(request=request, user=request.user)
+        exportables = ExportableModelsForUser(request=request, user=request.user)
         selected_models = []
         for exportable in exportables:
             selected_models.extend(request.POST.getlist(f"chk_{exportable}_models") or [])
