@@ -1,8 +1,7 @@
+from clinicedc_constants import UUID_PATTERN
 from django.apps import apps as django_apps
 from django.core.exceptions import ObjectDoesNotExist
 
-from edc_constants.constants import UUID_PATTERN
-
 from .fieldsets import Fieldsets
 
 
