@@ -9,6 +9,4 @@ def update_panels_on_post_migrate(sender, **kwargs):
 
     site_labs.migrated = True
     if site_labs.loaded:
-        site_labs.update_panel_model(
-            panel_model_cls=django_apps.get_model("edc_lab.panel")
-        )
+        site_labs.update_panel_model(panel_model_cls=django_apps.get_model("edc_lab.panel"))
