@@ -14,7 +14,7 @@ class FormActionViewMixin(ContextMixin):
     action_name = None
     form_action_name = "form_action"
     form_action_selected_items_name = "selected_items"
-    form_action_url = None
+    form_action_url = None  # url name
 
     def get_context_data(self, **kwargs) -> dict[str, Any]:
         kwargs.update(
