@@ -1,8 +1,8 @@
 from typing import Any
 
+from clinicedc_constants import FASTING, YES
 from django import forms
 
-from edc_constants.constants import FASTING, YES
 from edc_glucose.utils import validate_glucose_as_millimoles_per_liter
 
 
