@@ -1,7 +1,7 @@
+from clinicedc_constants import MILLIGRAMS_PER_DECILITER, MILLIMOLES_PER_LITER
 from django.db import models
 
-from edc_reportable import MILLIMOLES_PER_LITER_DISPLAY
-from edc_reportable.units import MILLIGRAMS_PER_DECILITER, MILLIMOLES_PER_LITER
+from edc_reportable.units import MILLIMOLES_PER_LITER_DISPLAY
 
 from ..model_mixin_factories import reportable_result_model_mixin_factory
 
