@@ -1,9 +1,10 @@
+from clinicedc_constants import MICRO_IU_MILLILITER
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import models
 
 from edc_constants.choices import YES_NO
 from edc_glucose.model_mixin_factories import fasting_model_mixin_factory
-from edc_reportable.units import MICRO_IU_MILLILITER, MICRO_IU_MILLILITER_DISPLAY
+from edc_reportable.units import MICRO_IU_MILLILITER_DISPLAY
 
 from ..model_mixin_factories import reportable_result_model_mixin_factory
 
