@@ -1,8 +1,7 @@
+from clinicedc_constants import MILLIMOLES_PER_LITER
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import models
 
-from edc_reportable.units import MILLIMOLES_PER_LITER
-
 from ..model_mixin_factories import reportable_result_model_mixin_factory
 
 
