@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+import contextlib
+
 from django.apps import AppConfig
 
 from .list_model_maker import ListModelMaker, ListModelMakerError
@@ -10,7 +12,7 @@ class LoadListDataError(Exception):
 
 
 def load_list_data(
-    list_data: dict = None, model_name: str | None = None, apps: AppConfig | None = None
+    list_data: dict | None = None, model_name: str | None = None, apps: AppConfig | None = None
 ) -> int:
     """Loads data into a list model.
 
@@ -24,25 +26,20 @@ def load_list_data(
          (name2, display_name),...],
         ...}
     """
-    if model_name:
-        model_names = [model_name]
-    else:
-        model_names = [k for k in list_data.keys()]
+    model_names = [model_name] if model_name else [k for k in list_data]
     n = 0
-    for model_name in model_names:
+    for _model_name in model_names:
         try:
-            data = list_data.get(model_name)()
+            data = list_data.get(_model_name)()
         except TypeError:
-            data = list_data.get(model_name)
+            data = list_data.get(_model_name)
         try:
             for display_index, row in enumerate(data):
-                try:
-                    row = row()
-                except TypeError:
-                    pass
-                maker = ListModelMaker(display_index, row, model_name, apps=apps)
+                with contextlib.suppress(TypeError):
+                    row = row()  # noqa: PLW2901
+                maker = ListModelMaker(display_index, row, _model_name, apps=apps)
                 maker.create_or_update()
         except ListModelMakerError as e:
-            raise LoadListDataError(f"{e} See {list_data.get(model_name)}.")
+            raise LoadListDataError(f"{e} See {list_data.get(_model_name)}.") from e
         n += 1
     return n
