@@ -6,7 +6,7 @@ style = color_style()
 
 
 def post_migrate_list_data(sender=None, **kwargs):
-    from .site_list_data import get_autodiscover_enabled, site_list_data
+    from .site_list_data import get_autodiscover_enabled, site_list_data  # noqa: PLC0415
 
     if get_autodiscover_enabled():
         sys.stdout.write(style.MIGRATE_HEADING("Updating list data:\n"))
