@@ -1,10 +1,10 @@
+from clinicedc_constants import NO, YES
 from django.contrib import admin
 from django.template.loader import render_to_string
 from django.utils import timezone
 from django_audit_fields.admin import audit_fieldset_tuple
 
 from edc_consent import site_consents
-from edc_constants.constants import NO, YES
 from edc_model_admin.mixins import ModelAdminProtectPiiMixin
 from edc_sites import site_sites
 from edc_utils.age import age
