@@ -1,5 +1,6 @@
+from clinicedc_constants import HIGH_PRIORITY
+
 from edc_action_item.action_with_notification import ActionWithNotification
-from edc_constants.constants import HIGH_PRIORITY
 from edc_offstudy.constants import END_OF_STUDY_ACTION
 from edc_visit_tracking.constants import VISIT_MISSED_ACTION
 
@@ -19,5 +20,4 @@ class LtfuAction(ActionWithNotification):
     priority = HIGH_PRIORITY
 
     def get_next_actions(self):
-        next_actions = [END_OF_STUDY_ACTION]
-        return next_actions
+        return [END_OF_STUDY_ACTION]
