@@ -49,6 +49,8 @@ class MetadataModelAdminMixin(
 
     change_search_field_name = "subject_identifier"
 
+    subject_dashboard_url_name = "subject_dashboard_url"  # url_name
+
     fieldsets = (
         [
             None,
@@ -149,8 +151,6 @@ class MetadataModelAdminMixin(
         extra_context.update(show_cancel=True)
         return extra_context
 
-    subject_dashboard_url_name = "subject_dashboard_url"
-
     def get_subject_dashboard_url(self, obj=None) -> str | None:
         opts = {}
         if obj:
@@ -195,9 +195,11 @@ class MetadataModelAdminMixin(
             )
         return obj.get_entry_status_display()
 
-    def get_view_on_site_url(self, obj=None):
+    def get_view_on_site_url(self, obj=None) -> None | str:
+        url = None
         if obj is None or not self.view_on_site:
-            return None
+            url = None
         if hasattr(obj, "get_absolute_url"):
             url = reverse(self.changelist_url)
-            return f"{url}?q={obj.subject_identifier}"
+            url = f"{url}?q={obj.subject_identifier}"
+        return url
