@@ -6,5 +6,5 @@ from ...metadata_rules import site_metadata_rules
 class Command(BaseCommand):
     help = "Performs a `get_model` for each target models referenced"
 
-    def handle(self, *args, **options):
+    def handle(self, *args, **options):  # noqa: ARG002
         site_metadata_rules.validate()
