@@ -42,13 +42,13 @@ class RuleGroupMetaOptions:
         # source model
         self.source_model = self.options.get("source_model")
         if self.source_model:
-            if len(self.source_model.split(".")) != 2:
+            if len(self.source_model.split(".")) != 2:  # noqa: PLR2004
                 self.source_model = f"{self.app_label}.{self.source_model}"
             self.options.update(source_model=self.source_model)
         # related visit model
         self.related_visit_model = self.options.get("related_visit_model")
         if self.related_visit_model:
-            if len(self.related_visit_model.split(".")) != 2:
+            if len(self.related_visit_model.split(".")) != 2:  # noqa: PLR2004
                 raise RuleGroupMetaError(
                     "Invalid _meta attr. Expected _meta.related_visit_model to be in "
                     f"label_lower format. Got '{self.related_visit_model}'. See {group_name}."
