@@ -43,10 +43,9 @@ class CreatesMetadataModelMixin(RelatedVisitProtocol, models.Model):
 
         Also called by post_save signal after metadata is updated.
         """
-        metadata_rule_evaluator = self.metadata_rule_evaluator_cls(
+        return self.metadata_rule_evaluator_cls(
             related_visit=self, allow_create=allow_create
-        )
-        metadata_rule_evaluator.evaluate_rules()
+        ).evaluate_rules()
 
     @property
     def metadata_query_options(self) -> dict[str, Any]:
@@ -54,14 +53,13 @@ class CreatesMetadataModelMixin(RelatedVisitProtocol, models.Model):
         the related_visit.
         """
         visit: Visit = self.visits.get(self.appointment.visit_code)
-        options = dict(
+        return dict(
             visit_schedule_name=self.appointment.visit_schedule_name,
             schedule_name=self.appointment.schedule_name,
             visit_code=visit.code,
             visit_code_sequence=self.appointment.visit_code_sequence,
             timepoint=self.appointment.timepoint,
         )
-        return options
 
     @property
     def crf_metadata(self):
