@@ -1,6 +1,6 @@
+from clinicedc_constants import LIVE, TEST
 from django.conf import settings
 
-from edc_constants.constants import LIVE, TEST
 from edc_protocol.research_protocol_config import ResearchProtocolConfig
 
 
