@@ -2,30 +2,36 @@ from __future__ import annotations
 
 import contextlib
 from copy import copy
+from typing import TYPE_CHECKING
 
 import numpy as np
 import pandas as pd
 from clinicedc_constants import NULL_STRING
 from django.apps import apps as django_apps
-from django.contrib.sites.models import Site
 from django.core.exceptions import FieldError
-from django.db import OperationalError
 from django.db.models import QuerySet
 from django_crypto_fields.utils import get_encrypted_fields, has_encrypted_fields
 from django_pandas.io import read_frame
 
-from edc_lab.models import Panel
-from edc_list_data.model_mixins import ListModelMixin, ListUuidModelMixin
+from edc_sites.utils import get_site_model_cls
 
 from .constants import ACTION_ITEM_COLUMNS, SYSTEM_COLUMNS
 
 __all__ = ["ModelToDataframe", "ModelToDataframeError"]
 
 
+if TYPE_CHECKING:
+    pass
+
+
 class ModelToDataframeError(Exception):
     pass
 
 
+class ModelToDataframeRowCountError(Exception):
+    pass
+
+
 class ModelToDataframe:
     """A class to return a model or queryset as a pandas dataframe
     with custom handling for EDC models.
@@ -37,7 +43,7 @@ class ModelToDataframe:
     Protections are in place for models or related models with
     encrypted fields.
 
-    We are not using django_pandas read_frame since a model class
+    This class extendd django_pandas read_frame since a model class
     may have M2M fields and read_frame does not handle M2M fields
     well. read_frame does not know about edc encrypted fields.
 
@@ -78,13 +84,14 @@ class ModelToDataframe:
     ):
         self._columns = None
         self._has_encrypted_fields = None
-        self._list_columns = None
+        self._list_model_related_columns = None
         self._encrypted_columns = None
         self._site_columns = None
         self._dataframe = pd.DataFrame()
+        self._model_field_names: list[str] = []
         self.read_frame_verbose = False if read_frame_verbose is None else read_frame_verbose
         self.sites = sites
-        self.drop_sys_columns = True if drop_sys_columns is None else drop_sys_columns
+        self.drop_sys_columns = drop_sys_columns
         self.drop_action_item_columns = (
             True if drop_action_item_columns is None else drop_action_item_columns
         )
@@ -92,39 +99,18 @@ class ModelToDataframe:
         self.m2m_columns = []
         self.query_filter = query_filter or {}
         self.remove_timezone = True if remove_timezone is None else remove_timezone
-        if queryset:
-            self.model = queryset.model._meta.label_lower
-        else:
-            self.model = model
+        self.queryset = queryset
+        self.model = queryset.model._meta.label_lower if self.queryset else model
+
         try:
             self.model_cls = django_apps.get_model(self.model)
         except LookupError as e:
             raise LookupError(f"Model is {self.model}. Got `{e}`") from e
-        if self.sites:
-            try:
-                if queryset:
-                    self.queryset = queryset.filter(site__in=sites)
-                else:
-                    self.queryset = self.model_cls.objects.filter(site__in=sites)
-            except FieldError as e:
-                if "Cannot resolve keyword 'site' into field" not in str(e):
-                    raise
-                self.queryset = queryset or self.model_cls.objects.all()
-        else:
-            self.queryset = queryset or self.model_cls.objects.all()
-        # trigger query
-        self.row_count = self.get_row_count()
 
-    def get_row_count(self):
-        try:
-            row_count = self.queryset.count()
-        except OperationalError as e:
-            if "The user specified as a definer" in str(e) and self.model_cls.recreate_db_view:
-                self.model_cls.recreate_db_view()
-                row_count = self.queryset.count()
-            else:
-                raise
-        return row_count
+        if (
+            self.sites and "site" in self.model_field_names
+        ) or "site_id" in self.model_field_names:
+            self.query_filter.update({"site__in": self.sites})
 
     @property
     def dataframe(self) -> pd.DataFrame:
@@ -138,56 +124,72 @@ class ModelToDataframe:
             column "visit_reason" would become a Dataframe instead
             of a Series like all other columns.
         """
-        if self._dataframe.empty and self.row_count > 0:
-            if self.decrypt and self.has_encrypted_fields:
-                dataframe = self.get_dataframe_with_encrypted_fields(self.row_count)
-            else:
-                dataframe = self.get_dataframe_without_encrypted_fields()
+        if self._dataframe.empty:
+            model_row_count = (
+                (self.queryset or self.model_cls.objects)
+                .filter(**self.query_filter)
+                .all()
+                .count()
+            )
 
-            dataframe = self.merge_m2ms(dataframe)
+            df = read_frame(
+                (self.queryset or self.model_cls.objects)
+                .values(*self.columns)
+                .filter(**self.query_filter)
+                .all(),
+                verbose=self.read_frame_verbose,
+            )[[col for col in self.columns]]
 
-            dataframe = dataframe.rename(columns=self.columns)
+            self.validate_row_count(model_row_count, df, step_name="read_frame")
+
+            df = self.merge_m2ms(df)
+
+            self.validate_row_count(model_row_count, df, step_name="m2m")
+
+            df = df.rename(columns=self.columns)
 
             # remove timezone if asked
             if self.remove_timezone:
-                for column in list(dataframe.select_dtypes(include=["datetimetz"]).columns):
-                    dataframe[column] = pd.to_datetime(dataframe[column]).dt.tz_localize(None)
+                for column in list(
+                    df.select_dtypes(include=["datetimetz", "datetime64"]).columns
+                ):
+                    df[column] = pd.to_datetime(df[column]).dt.tz_localize(None)
 
             # convert bool to int64
-            for column in list(dataframe.select_dtypes(include=["bool"]).columns):
-                dataframe[column] = (
-                    dataframe[column].astype("int64").replace({True: 1, False: 0})
-                )
+            for column in list(df.select_dtypes(include=["bool"]).columns):
+                df[column] = df[column].astype("int64").replace({True: 1, False: 0})
 
             # convert object to str
-            for column in list(dataframe.select_dtypes(include=["object"]).columns):
-                dataframe[column] = dataframe[column].fillna("")
-                dataframe[column] = dataframe[column].astype(str)
+            for column in list(df.select_dtypes(include=["object"]).columns):
+                df[column] = df[column].fillna("")
+                df[column] = df[column].astype(str)
 
             # convert timedeltas to secs
-            for column in list(dataframe.select_dtypes(include=["timedelta64"]).columns):
-                dataframe[column] = dataframe[column].dt.total_seconds()
+            for column in list(df.select_dtypes(include=["timedelta64"]).columns):
+                df[column] = df[column].dt.total_seconds()
 
             # fillna
-            dataframe = dataframe.fillna(value=np.nan, axis=0)
+            df = df.fillna(value=np.nan, axis=0)
 
             # remove illegal chars
-            for column in list(dataframe.select_dtypes(include=["object"]).columns):
-                dataframe[column] = dataframe.apply(
-                    lambda x, col=column: self._clean_chars(x[col]), axis=1
-                )
-            self._dataframe = dataframe
+            for column in list(df.select_dtypes(include=["object"]).columns):
+                df[column] = df.apply(lambda x, col=column: self._clean_chars(x[col]), axis=1)
+
+            # check merges worked correctly
+            self.validate_row_count(model_row_count, df, step_name="final")
+            self._dataframe = df
         return self._dataframe
 
-    def get_dataframe_without_encrypted_fields(self) -> pd.DataFrame:
-        queryset = self.queryset.values_list(*self.columns).filter(**self.query_filter)
-        return pd.DataFrame(list(queryset), columns=[v for v in self.columns])
-
-    def get_dataframe_with_encrypted_fields(self, row_count: int) -> pd.DataFrame:  # noqa: ARG002
-        df = read_frame(
-            self.queryset.filter(**self.query_filter), verbose=self.read_frame_verbose
-        )
-        return df[[col for col in self.columns]]
+    def validate_row_count(
+        self, model_row_count: int, df: pd.DataFrame, step_name: str
+    ) -> bool:
+        if model_row_count != len(df):
+            model = (self.queryset or self.model_cls)._meta.label_lower
+            raise ModelToDataframeRowCountError(
+                "Dataframe row count mismatch. "
+                f"See {model}. Expected {model_row_count}. Got {len(df)} at step {step_name}."
+            )
+        return True
 
     def merge_m2ms(self, dataframe):
         """Merge m2m data into main dataframe.
@@ -223,9 +225,13 @@ class ModelToDataframe:
                 .filter(**{f"{m2m_field_name}__isnull": False})
                 .values("id", m2m_field_name)
             )
-            df_m2m = df_m2m.groupby("id")[m2m_field_name].apply(",".join).reset_index()
-            df_m2m = df_m2m.rename(columns={m2m_field_name: m2m_field_name.split("__")[0]})
-            dataframe = dataframe.merge(df_m2m, on="id", how="left")
+            df_m2m = (
+                df_m2m.groupby("id")[m2m_field_name]
+                .apply(",".join)
+                .reset_index()
+                .rename(columns={m2m_field_name: m2m_field_name.split("__")[0]})
+            )
+            dataframe = dataframe.merge(df_m2m, on="id", how="left").reset_index(drop=True)
         return dataframe
 
     def _clean_chars(self, s: str) -> str:
@@ -272,21 +278,18 @@ class ModelToDataframe:
 
     @property
     def columns(self) -> dict[str, str]:
-        """Return a dictionary of column names."""
+        """Return a dictionary of column names for the Dataframe."""
         if not self._columns:
-            columns_list = self.get_columns_list()
-            columns = {col: col for col in columns_list}
-            for column_name in columns_list:
-                if column_name.endswith("_visit_id"):
+            columns = {col: col for col in self.model_field_names}
+            for field_name in self.model_field_names:
+                if field_name.endswith("_visit_id"):
                     with contextlib.suppress(FieldError):
-                        columns = self.add_columns_for_subject_visit(
-                            column_name=column_name, columns=columns
-                        )
-                if column_name.endswith("_requisition") or column_name.endswith(
+                        columns = self.add_columns_for_subject_visit(field_name, columns)
+                if field_name.endswith("_requisition") or field_name.endswith(
                     "requisition_id"
                 ):
                     columns = self.add_columns_for_subject_requisitions(columns)
-            columns = self.add_columns_for_site(columns=columns)
+            columns = self.add_columns_for_site(columns)
             columns = self.add_list_model_name_columns(columns)
             columns = self.add_other_columns(columns)
             columns = self.add_subject_identifier_column(columns)
@@ -298,47 +301,52 @@ class ModelToDataframe:
             self._columns = columns
         return self._columns
 
-    def get_columns_list(self) -> list[str]:
-        try:
-            columns_list = list(self.queryset.first().__dict__.keys())
-        except AttributeError as e:
-            if "__dict__" in str(e):
-                columns_list = list(self.queryset._fields)
-            else:
-                raise
-        for name in self.sys_field_names:
-            with contextlib.suppress(ValueError):
-                columns_list.remove(name)
-        if not self.decrypt:
-            columns_list = [col for col in columns_list if col not in self.encrypted_columns]
-        return columns_list
+    @property
+    def model_field_names(self) -> list[str]:
+        if not self._model_field_names:
+            self._model_field_names = [
+                f.attname
+                for f in self.model_cls._meta.get_fields()
+                if f.concrete and not f.many_to_many
+            ]
+            for name in self.sys_field_names:
+                with contextlib.suppress(ValueError):
+                    self._model_field_names.remove(name)
+            if not self.decrypt:
+                self._model_field_names = [
+                    col for col in self._model_field_names if col not in self.encrypted_columns
+                ]
+        return self._model_field_names
 
     @property
     def encrypted_columns(self) -> list[str]:
         """Return a sorted list of column names that use encryption."""
         if not self._encrypted_columns:
-            self._encrypted_columns = [
-                field.name for field in get_encrypted_fields(self.model_cls)
-            ]
-            self._encrypted_columns = list(set(self._encrypted_columns))
+            self._encrypted_columns = list(
+                set([f.name for f in get_encrypted_fields(self.model_cls)])
+            )
             self._encrypted_columns.sort()
         return self._encrypted_columns
 
     @property
-    def list_columns(self) -> list[str]:
-        """Return a list of column names with fk to a list model."""
+    def list_model_related_columns(self) -> list[str]:
+        """Return a list of column names with fk to a ListModel."""
+        from edc_list_data.model_mixins import (  # noqa: PLC0415
+            ListModelMixin,
+            ListUuidModelMixin,
+        )
 
-        if not self._list_columns:
-            list_columns = []
+        if not self._list_model_related_columns:
+            list_model_related_columns = []
             for fld_cls in self.model_cls._meta.get_fields():
                 if (
                     hasattr(fld_cls, "related_model")
                     and fld_cls.related_model
                     and issubclass(fld_cls.related_model, (ListModelMixin, ListUuidModelMixin))
                 ):
-                    list_columns.append(fld_cls.attname)  # noqa: PERF401
-            self._list_columns = list(set(list_columns))
-        return self._list_columns
+                    list_model_related_columns.append(fld_cls.attname)  # noqa: PERF401
+            self._list_model_related_columns = list(set(list_model_related_columns))
+        return self._list_model_related_columns
 
     @property
     def site_columns(self) -> list[str]:
@@ -350,27 +358,27 @@ class ModelToDataframe:
                 if (
                     hasattr(fld_cls, "related_model")
                     and fld_cls.related_model
-                    and issubclass(fld_cls.related_model, (Site,))
+                    and issubclass(fld_cls.related_model, (get_site_model_cls(),))
                 ):
-                    site_columns.append(fld_cls.attname)
+                    site_columns.append(fld_cls.attname)  # noqa: PERF401
             self._site_columns = list(set(site_columns))
         return self._site_columns
 
     @property
     def other_columns(self) -> list[str]:
-        """Return other column names with fk to a common models."""
-        related_model = [Site, Panel]
-        if not self._list_columns:
-            list_columns = []
+        """Return OTHER column names with fk to a common models."""
+        related_model = [get_site_model_cls(), django_apps.get_model("edc_lab.panel")]
+        if not self._list_model_related_columns:
+            list_model_related_columns = []
             for fld_cls in self.model_cls._meta.get_fields():
                 if (
                     hasattr(fld_cls, "related_model")
                     and fld_cls.related_model
                     and fld_cls.related_model in related_model
                 ):
-                    list_columns.append(fld_cls.attname)
-            self._list_columns = list(set(list_columns))
-        return self._list_columns
+                    list_model_related_columns.append(fld_cls.attname)  # noqa: PERF401
+            self._list_model_related_columns = list(set(list_model_related_columns))
+        return self._list_model_related_columns
 
     def add_subject_identifier_column(self, columns: dict[str, str]) -> dict[str, str]:
         if "subject_identifier" not in [v for v in columns.values()]:
@@ -391,7 +399,7 @@ class ModelToDataframe:
 
     @staticmethod
     def add_columns_for_subject_visit(
-        column_name: str = None, columns: dict[str, str] = None
+        column_name: str, columns: dict[str, str]
     ) -> dict[str, str]:
         if "subject_identifier" not in [v for v in columns.values()]:
             columns.update(
@@ -407,9 +415,7 @@ class ModelToDataframe:
         return columns
 
     @staticmethod
-    def add_columns_for_subject_requisitions(
-        columns: dict[str, str] = None,
-    ) -> dict[str, str]:
+    def add_columns_for_subject_requisitions(columns: dict[str, str]) -> dict[str, str]:
         for col in copy(columns):
             if col.endswith("_requisition_id"):
                 col_prefix = col.split("_")[0]
@@ -427,21 +433,21 @@ class ModelToDataframe:
                 columns.update({f"{column_name}__is_drawn": f"{col_prefix}_is_drawn"})
         return columns
 
-    def add_columns_for_site(self, columns: dict[str, str] = None) -> dict[str, str]:
+    def add_columns_for_site(self, columns: dict[str, str]) -> dict[str, str]:
         for col in copy(columns):
             if col in self.site_columns:
                 col_prefix = col.split("_id")[0]
                 columns.update({f"{col_prefix}__name": f"{col_prefix}_name"})
         return columns
 
-    def add_list_model_name_columns(self, columns: dict[str, str] = None) -> dict[str, str]:
+    def add_list_model_name_columns(self, columns: dict[str, str]) -> dict[str, str]:
         for col in copy(columns):
-            if col in self.list_columns:
+            if col in self.list_model_related_columns:
                 column_name = col.split("_id")[0]
                 columns.update({f"{column_name}__name": f"{column_name}_name"})
         return columns
 
-    def add_other_columns(self, columns: dict[str, str] = None) -> dict[str, str]:
+    def add_other_columns(self, columns: dict[str, str]) -> dict[str, str]:
         for col in copy(columns):
             if col in self.other_columns:
                 column_name = col.split("_id")[0]
