@@ -1,7 +1,6 @@
+from clinicedc_constants import NULL_STRING
 from django.db import models
 
-from edc_constants.constants import NULL_STRING
-
 
 class AddressModelMixin(models.Model):
     address_one = models.CharField(max_length=255, default=NULL_STRING, blank=True)
