@@ -1,7 +1,7 @@
+from clinicedc_constants import NEW
 from django.db import models
 from sequences import get_next_value
 
-from edc_constants.constants import NEW
 from edc_model.models import BaseUuidModel, HistoricalRecords
 
 from ...choices import ORDER_CHOICES
