@@ -1,9 +1,9 @@
 from django.apps import apps as django_apps
 from django.db import models
+from django.utils import timezone
 
 from edc_model.models import BaseUuidModel
 from edc_sites.model_mixins import SiteModelMixin
-from edc_utils import get_utcnow
 
 from ..choices import NOTE_STATUSES
 
@@ -17,14 +17,15 @@ class NoteModelMixin(SiteModelMixin, BaseUuidModel):
 
     report_model = models.CharField(max_length=150)
 
-    report_datetime = models.DateTimeField(default=get_utcnow)
+    report_datetime = models.DateTimeField(default=timezone.now)
 
-    note = models.TextField(null=True, blank=True)
-
-    status = models.CharField(
-        max_length=25, choices=NOTE_STATUSES, null=True, blank=False
+    note = models.TextField(
+        default="",
+        blank=True,
     )
 
+    status = models.CharField(max_length=25, choices=NOTE_STATUSES, default="", blank=False)
+
     @property
     def report_model_cls(self):
         return django_apps.get_model(self.report_model)
