@@ -1,5 +1,5 @@
+import contextlib
 import sys
-from pathlib import Path
 from warnings import warn
 
 from django.apps import apps as django_apps
@@ -9,35 +9,6 @@ from django.db import OperationalError, connection
 from edc_auth.get_app_codenames import get_app_codenames
 
 
-def read_unmanaged_model_sql(
-    filename: str | None = None,
-    app_name: str | None = None,
-    fullpath: str | Path | None = None,
-) -> str:
-    """Wait, use DBView instead!!"""
-    uuid_func = "uuid()"
-    if settings.DATABASES["default"]["ENGINE"] == "django.db.backends.postgresql":
-        uuid_func = "gen_random_uuid()"
-
-    if not fullpath:
-        fullpath = Path(settings.BASE_DIR) / app_name / "models" / "unmanaged" / filename
-    else:
-        fullpath = Path(fullpath)
-
-    parsed_sql = []
-    with fullpath.open("r") as f:
-        for line in f:
-            line = line.split("#", maxsplit=1)[0]
-            line = line.split("-- ", maxsplit=1)[0]
-            line = line.replace("\n", "")
-            line = line.strip()
-            if line:
-                parsed_sql.append(line)
-
-    sql = " ".join(parsed_sql)
-    return sql.replace("uuid()", uuid_func)
-
-
 def get_qareports_codenames(app_name: str, *note_models: str) -> list[str]:
     warn(
         "This function has been deprecated. Use get_app_codenames.",
@@ -88,17 +59,15 @@ def recreate_db_view(model_cls, drop: bool | None = None, verbose: bool | None =
     except AttributeError as e:
         raise AttributeError(
             f"Is this model linked to a view? Declare model with `DBView`. Got {e}"
-        )
+        ) from e
     else:
         sql = sql.replace(";", "")
         if verbose:
-            print(f"create view {model_cls._meta.db_table} as {sql};")
+            sys.stdout.write(f"create view {model_cls._meta.db_table} as {sql};\n")
         with connection.cursor() as c:
             if drop:
-                try:
+                with contextlib.suppress(OperationalError):
                     c.execute(f"drop view {model_cls._meta.db_table};")
-                except OperationalError:
-                    pass
             c.execute(f"create view {model_cls._meta.db_table} as {sql};")
         if verbose:
             sys.stdout.write(
@@ -107,14 +76,14 @@ def recreate_db_view(model_cls, drop: bool | None = None, verbose: bool | None =
 
 
 def recreate_dbview_for_all():
-    from .model_mixins import QaReportModelMixin
+    from .model_mixins import QaReportModelMixin  # noqa: PLC0415
 
     for model_cls in django_apps.get_models():
         if issubclass(model_cls, (QaReportModelMixin,)):
-            print(model_cls)
+            sys.stdout.write(f"{model_cls}\n")
             try:
                 model_cls.recreate_db_view()
             except AttributeError as e:
-                print(e)
+                sys.stdout.write(f"{e}\n")
             except TypeError as e:
-                print(e)
+                sys.stdout.write(f"{e}\n")
