@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import csv
 import sys
+from itertools import islice
 from pathlib import Path
 from pprint import pprint
 from uuid import uuid4
@@ -12,21 +13,16 @@ from tqdm import tqdm
 
 from edc_sites.site import sites as site_sites
 
+from .exceptions import (
+    InvalidAssignment,
+    RandomizationListAlreadyImported,
+    RandomizationListImportError,
+)
 from .randomization_list_verifier import RandomizationListVerifier
 
 style = color_style()
 
-
-class RandomizationListImportError(Exception):
-    pass
-
-
-class RandomizationListAlreadyImported(Exception):
-    pass
-
-
-class InvalidAssignment(Exception):
-    pass
+__all__ = ["RandomizationListImporter"]
 
 
 class RandomizationListImporter:
@@ -55,31 +51,33 @@ class RandomizationListImporter:
 
 
     Format:
-        sid,assignment,site_name, orig_site, orig_allocation, orig_desc
-        1,single_dose,gaborone
-        2,two_doses,gaborone
+        sid,site_name, assignment, description, orig_site, orig_allocation, orig_desc
+        1,gaborone,intervention,single_dose
+        2,gaborone,control,two_doses
         ...
     """
 
-    required_csv_fieldnames = ["sid", "assignment", "site_name"]
+    required_csv_fieldnames = ("sid", "assignment", "site_name", "description")
     verifier_cls = RandomizationListVerifier
 
     def __init__(
         self,
         randomizer_model_cls=None,
-        randomizer_name: str = None,
-        randomizationlist_path: Path | str = None,
-        assignment_map: dict[str, int] = None,
-        verbose: bool = None,
-        overwrite: bool = None,
-        add: bool = None,
-        dryrun: bool = None,
-        username: str = None,
-        revision: str = None,
-        sid_count_for_tests: int = None,
-        extra_csv_fieldnames: list[str] | None = None,
-        **kwargs,
+        randomizer_name: str | None = None,
+        randomizationlist_path: Path | str | None = None,
+        assignment_map: dict[str, int] | None = None,
+        verbose: bool | None = None,
+        overwrite: bool | None = None,
+        add: bool | None = None,
+        dryrun: bool | None = None,
+        username: str | None = None,
+        revision: str | None = None,
+        sid_count_for_tests: int | None = None,
+        skip_verify: bool | None = None,
+        extra_csv_fieldnames: tuple[str] | None = None,
+        **kwargs,  # noqa: ARG002
     ):
+        extra_csv_fieldnames = extra_csv_fieldnames or ()
         self.verify_messages: str | None = None
         self.add = add
         self.overwrite = overwrite
@@ -88,11 +86,12 @@ class RandomizationListImporter:
         self.revision = revision
         self.user = username
         self.sid_count_for_tests = sid_count_for_tests
+        self.skip_verify = skip_verify
         self.randomizer_model_cls = randomizer_model_cls
         self.randomizer_name = randomizer_name
         self.assignment_map = assignment_map
         self.randomizationlist_path: Path = Path(randomizationlist_path).expanduser()
-        self.required_csv_fieldnames.extend(extra_csv_fieldnames or [])
+        self.required_csv_fieldnames = (*self.required_csv_fieldnames, *extra_csv_fieldnames)
 
         if self.dryrun:
             sys.stdout.write(
@@ -124,8 +123,9 @@ class RandomizationListImporter:
                 )
             )
         rec_count = self._import_csv_to_model()
-        self.verify_messages = self._verify_data(**kwargs)
-        self._summarize_results()
+        if not self.skip_verify:
+            self.verify_messages = self._verify_data(**kwargs)
+            self._summarize_results()
         if self.verbose:
             sys.stdout.write(
                 style.SUCCESS("\nDone.------------------------------------------------\n")
@@ -156,7 +156,7 @@ class RandomizationListImporter:
         index = 0
         with self.randomizationlist_path.open(mode="r") as csvfile:
             reader = csv.DictReader(csvfile)
-            for index, row in enumerate(reader):
+            for index, _ in enumerate(reader):
                 if index == 0:
                     continue
         if index == 0:
@@ -178,11 +178,11 @@ class RandomizationListImporter:
                 elif index == 1:
                     if self.dryrun:
                         row_as_dict = {k: v for k, v in row.items()}
-                        print(" -->  First row:")
-                        print(f" -->  {list(row_as_dict.keys())}")
-                        print(f" -->  {list(row_as_dict.values())}")
+                        sys.stdout.write(" -->  First row:\n")
+                        sys.stdout.write(f" -->  {list(row_as_dict.keys())}\n")
+                        sys.stdout.write(f" -->  {list(row_as_dict.values())}\n")
                         obj = self.randomizer_model_cls(**self.get_import_options(row))
-                        pprint(obj.__dict__)
+                        pprint(obj.__dict__)  # noqa: T203
                 else:
                     break
 
@@ -223,12 +223,17 @@ class RandomizationListImporter:
             sid_count = self.sid_count_for_tests
         else:
             sid_count = len(self.get_sid_list())
-        with self.randomizationlist_path.open(mode="r") as csvfile:
-            reader = csv.DictReader(csvfile)
-            for row in tqdm(reader, total=sid_count):
-                if self.sid_count_for_tests and len(objs) == self.sid_count_for_tests:
-                    break
-                row = {k: v.strip() for k, v in row.items()}
+        with self.randomizationlist_path.open(mode="r") as f:
+            reader = csv.DictReader(f)
+            if self.sid_count_for_tests:
+                reader = islice(reader, self.sid_count_for_tests)
+            all_rows = [{k: v.strip() for k, v in row.items() if k} for row in reader]
+            sorted_rows = sorted(
+                all_rows, key=lambda row: (row.get("site_name", ""), row.get("sid", ""))
+            )
+            for row in tqdm(sorted_rows, total=sid_count):
+                # if self.sid_count_for_tests and len(objs) == self.sid_count_for_tests:
+                #     break
                 try:
                     self.randomizer_model_cls.objects.get(sid=row["sid"])
                 except ObjectDoesNotExist:
@@ -300,7 +305,7 @@ class RandomizationListImporter:
             **self.get_extra_import_options(row),
         )
 
-    def get_extra_import_options(self, row):
+    def get_extra_import_options(self, row):  # noqa: ARG002
         return {}
 
     @staticmethod
@@ -314,9 +319,9 @@ class RandomizationListImporter:
         """Returns the site name or raises"""
         try:
             site_name = self.get_site_names()[row["site_name"].lower()]
-        except KeyError:
+        except KeyError as e:
             raise RandomizationListImportError(
                 f"Invalid site. Got {row['site_name']}. "
                 f"Expected one of {self.get_site_names().keys()}"
-            )
+            ) from e
         return site_name
