@@ -1,5 +1,6 @@
 import re
 
+from clinicedc_constants import UUID_PATTERN
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.validators import RegexValidator
 from django.db import models, transaction
@@ -13,7 +14,6 @@ from django_crypto_fields.fields import (
 )
 
 from edc_constants.choices import GENDER
-from edc_constants.constants import UUID_PATTERN
 from edc_identifier.model_mixins import UniqueSubjectIdentifierModelMixin
 from edc_model.models import BaseUuidModel, HistoricalRecords
 from edc_model_fields.fields import IdentityTypeField, IsDateEstimatedField
