@@ -13,7 +13,7 @@ class AgeEvaluator(Evaluator):
     def __init__(
         self,
         age_lower: int | None = None,
-        age_upper: int = None,
+        age_upper: int | None = None,
         age_units: str | None = None,
         age_lower_inclusive: bool | None = None,
         age_upper_inclusive: bool | None = None,
@@ -29,15 +29,15 @@ class AgeEvaluator(Evaluator):
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}({self.description(show_as_int=True)})"
 
-    def description(self, value: int = None, **kwargs):
+    def description(self, value: int | None = None, **kwargs):
         kwargs["show_as_int"] = True
         kwargs["placeholder"] = "AGE"
         return super().description(value=value, **kwargs)
 
     def in_bounds_or_raise(
         self,
-        dob: date = None,
-        report_datetime: datetime = None,
+        dob: date | None = None,
+        report_datetime: datetime | None = None,
         age_units: str | None = None,
     ) -> bool:
         report_datetime = report_datetime or timezone.now()
