@@ -1,6 +1,11 @@
-from edc_constants.constants import GRADE3, GRADE4, NO, NOT_APPLICABLE
-
-from .constants import ALREADY_REPORTED, PRESENT_AT_BASELINE
+from clinicedc_constants import (
+    ALREADY_REPORTED,
+    GRADE3,
+    GRADE4,
+    NO,
+    NOT_APPLICABLE,
+    PRESENT_AT_BASELINE,
+)
 
 REPORTABLE = (
     (NOT_APPLICABLE, "Not applicable"),
