@@ -10,7 +10,7 @@ app_name = "edc_review_dashboard"
 
 urlpatterns = SubjectReviewListboardView.urls(
     namespace=app_name,
-    label="subject_review_listboard",
+    url_names_key="subject_review_listboard_url",
     identifier_pattern=ResearchProtocolConfig().subject_identifier_pattern,
 )
 
@@ -18,3 +18,5 @@ urlpatterns += [
     path("admin/", admin.site.urls),
     path("", HomeView.as_view(), name="home_url"),
 ]
+
+# aliquot_listboard = ("edc_lab_dashboard:aliquot_listboard_url",)
