@@ -1,5 +1,6 @@
 from uuid import uuid4
 
+from clinicedc_constants import NO, NOT_APPLICABLE
 from django.core.validators import (
     MaxLengthValidator,
     MaxValueValidator,
@@ -12,7 +13,6 @@ from django.utils import timezone
 from django_crypto_fields.fields import EncryptedCharField
 
 from edc_constants.choices import GENDER, YES_NO, YES_NO_NA
-from edc_constants.constants import NO, NOT_APPLICABLE
 from edc_model.validators import datetime_not_future
 from edc_protocol.validators import datetime_not_before_study_start
 from edc_sites.model_mixins import SiteModelMixin
