@@ -2,11 +2,11 @@ from __future__ import annotations
 
 import re
 
+from clinicedc_constants import UUID_PATTERN
 from django import forms
 from django.urls.base import reverse
 from django.utils.html import format_html
 
-from edc_constants.constants import UUID_PATTERN
 from edc_dashboard.url_names import url_names
 
 
