@@ -44,7 +44,7 @@ class SubjectDashboardView(
     navbar_selected_item = "consented_subject"
 
     dashboard_url_name = "subject_dashboard_url"
-    dashboard_template = "subject_dashboard_template"
+    dashboard_template_name = "subject_dashboard_template"
 
     default_manager = "on_site"
 
