@@ -1,3 +1,4 @@
+from clinicedc_constants import TBD
 from django.core.validators import (
     MaxLengthValidator,
     MinLengthValidator,
@@ -8,7 +9,6 @@ from django.utils import timezone
 
 from edc_action_item.models.action_model_mixin import ActionModelMixin
 from edc_constants.choices import YES_NO_TBD
-from edc_constants.constants import TBD
 from edc_identifier.managers import SubjectIdentifierManager
 from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
 from edc_model.models.base_uuid_model import BaseUuidModel
