@@ -100,7 +100,7 @@ class SubjectScheduleHistoryAdmin(
     def review(obj=None) -> str:
         try:
             url = (
-                f"{reverse('edc_review_dashboard:subject_review_listboard_url')}?"
+                f"{reverse(url_names.get('subject_review_listboard_url'))}?"
                 f"q={obj.subject_identifier}"
             )
         except NoReverseMatch:
