@@ -1,16 +1,18 @@
 from typing import Any
 
+from clinicedc_constants import NO, YES
 from django.db import models
 from django.db.models.deletion import PROTECT
 
 from edc_appointment.appointment_status_updater import AppointmentStatusUpdater
 from edc_appointment.constants import MISSED_APPT
 from edc_consent.model_mixins import RequiresConsentFieldsModelMixin
-from edc_constants.constants import NO, YES
 from edc_document_status.model_mixins import DocumentStatusModelMixin
 from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
 from edc_metadata.model_mixins import MetadataHelperModelMixin
 from edc_offstudy.model_mixins import OffstudyNonCrfModelMixin
+from edc_timepoint.model_mixins import TimepointLookupModelMixin
+from edc_timepoint.visit_timepoint_lookup import VisitTimepointLookup
 from edc_visit_schedule.model_mixins import VisitScheduleModelMixin
 
 from ...constants import MISSED_VISIT, NO_FOLLOW_UP_REASONS
@@ -29,6 +31,7 @@ class VisitModelMixin(
     MetadataHelperModelMixin,
     OffstudyNonCrfModelMixin,
     RequiresConsentFieldsModelMixin,
+    TimepointLookupModelMixin,
     models.Model,
 ):
     """
@@ -41,6 +44,8 @@ class VisitModelMixin(
                 app_label = 'my_app'
     """
 
+    timepoint_lookup_cls = VisitTimepointLookup
+
     metadata_helper_instance_attr = None
 
     appointment = models.OneToOneField("edc_appointment.appointment", on_delete=PROTECT)
